==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/actor/nls/pt-br/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "Mensagens",
    ":DELETE_ADDRESS": "Apagar endere\u00e7o ${0}?",
    ":NEED_ADDRESS": "Um endere\u00e7o \u00e9 exigido durante o registro.",
    ":DUPE_PATRON_NAME": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo nome",
    ":DUPE_PATRON_EMAIL": "Encontrados ${0} padr(\u00e3o/\u00f5es) com a mesma dire\u00e7\u00e3o de email",
    ":DUPE_PATRON_IDENT": "Encontrados ${0} padr(\u00e3o/\u00f5es) com a mesma identifica\u00e7\u00e3o",
    ":DUPE_PATRON_PHONE": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo n\u00famero de telefone",
    ":DUPE_PATRON_ADDR": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo endere\u00e7o",
    ":REPLACED_ADDRESS": "Replaces address ${0}<br/> ${1} ${2}<br/> ${3}, ${4} ${5}",
    ":INVALID_FORM": "Formul\u00e1rio est\u00e1 inv\u00e1lido. Por favor, edite e tente novamente.",
    ":EXAMPLE": "Examplo: ",
    ":REPLACE_BARCODE": "Substituir C\u00f3digo-de-barras",
    ":BARCODE_IN_USE": "C\u00f3digo de Barras j\u00e1 est\u00e1 em uso",
    ":SEE_ALL": "Ver Todos",
    ":DUPE_USERNAME": "Nome de Usu\u00e1rio j\u00e1 est\u00e1 em uso",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Verificar Senha",
    ":PARENT_OR_GUARDIAN": "Pai/Guardi\u00e3o",
    ":USER_SETTINGS": "Configura\u00e7\u00f5es do Usu\u00e1rio",
    ":ADDRESS_HEADER": "Endere\u00e7o",
    ":ADDRESS_MAILING": "Correio",
    ":ADDRESS_BILLING": "Cobran\u00e7a",
    ":ADDRESS_PENDING": "Este \u00e9 um endere\u00e7o pendente: ",
    ":ADDRESS_APPROVE": "Aprovar Endere\u00e7o",
    ":ADDRESS_OWNED": "Este endere\u00e7o \u00e9 utilizado por outro usu\u00e1rio: ",
    ":ADDRESS_NEW": "Novo Endere\u00e7o",
    ":STAT_CATS": "Categorias Estat\u00edsticas",
    ":SAVE": "Salvar",
    ":SAVE_CLONE": "Salvar &amp; Clonar",
    ":SHOW_REQUIRED": "Mostrar somente Campos Obrigat\u00f3rios",
    ":SHOW_SUGGESTED": "Mostrar Campos Sugeridos",
    ":SHOW_ALL": "Mostar todos os campos",
    ":ALL_CARDS_BARCODE": "C\u00f3digo de barras",
    ":ALL_CARDS_ACTIVE": "Ativo",
    ":ALL_CARDS_PRIMARY": "Prim\u00e1rio",
    ":ALL_CARDS_CLOSE": "Fechar",
    ":ALL_CARDS_APPLY": "Aplicar Altera\u00e7\u00f5es",
    ":INVALIDATE": "Invalidar",
    ":HOLD_NOTIFY_PHONE": "Telefone: ",
    ":HOLD_NOTIFY_EMAIL": "E-mail: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}

==> Evergreen-ILS-3.16.3.tar.gz: Evergreen-ILS-3.16.3/Open-ILS/web/js/dojo/openils/actor/nls/pt-br/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "Mensagens",
    ":DELETE_ADDRESS": "Apagar endere\u00e7o ${0}?",
    ":NEED_ADDRESS": "Um endere\u00e7o \u00e9 exigido durante o registro.",
    ":DUPE_PATRON_NAME": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo nome",
    ":DUPE_PATRON_EMAIL": "Encontrados ${0} padr(\u00e3o/\u00f5es) com a mesma dire\u00e7\u00e3o de email",
    ":DUPE_PATRON_IDENT": "Encontrados ${0} padr(\u00e3o/\u00f5es) com a mesma identifica\u00e7\u00e3o",
    ":DUPE_PATRON_PHONE": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo n\u00famero de telefone",
    ":DUPE_PATRON_ADDR": "Encontrados ${0} padr(\u00e3o/\u00f5es) com o mesmo endere\u00e7o",
    ":REPLACED_ADDRESS": "<div>Substituir endere\u00e7o <b>${0}</b><br/> ${1} ${2}<br/> ${3}, ${4} ${5}</div>",
    ":INVALID_FORM": "Formul\u00e1rio est\u00e1 inv\u00e1lido. Por favor, edite e tente novamente.",
    ":EXAMPLE": "Examplo: ",
    ":REPLACE_BARCODE": "Substituir C\u00f3digo-de-barras",
    ":BARCODE_IN_USE": "C\u00f3digo de Barras j\u00e1 est\u00e1 em uso",
    ":SEE_ALL": "Ver Todos",
    ":DUPE_USERNAME": "Nome de Usu\u00e1rio j\u00e1 est\u00e1 em uso",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Verificar Senha",
    ":PARENT_OR_GUARDIAN": "Pai/Guardi\u00e3o",
    ":PARENT_OR_GUARDIAN_EMAIL": "Parent/Guardian Email",
    ":USER_SETTINGS": "Configura\u00e7\u00f5es do Usu\u00e1rio",
    ":ADDRESS_HEADER": "Endere\u00e7o",
    ":ADDRESS_MAILING": "Correio",
    ":ADDRESS_BILLING": "Cobran\u00e7a",
    ":ADDRESS_PENDING": "Este \u00e9 um endere\u00e7o pendente: ",
    ":ADDRESS_APPROVE": "Aprovar Endere\u00e7o",
    ":ADDRESS_OWNED": "Este endere\u00e7o \u00e9 utilizado por outro usu\u00e1rio: ",
    ":ADDRESS_NEW": "Novo Endere\u00e7o",
    ":STAT_CATS": "Categorias Estat\u00edsticas",
    ":SAVE": "Salvar",
    ":SAVE_CLONE": "Salvar &amp; Clonar",
    ":SHOW_REQUIRED": "Mostrar somente Campos Obrigat\u00f3rios",
    ":SHOW_SUGGESTED": "Mostrar Campos Sugeridos",
    ":SHOW_ALL": "Mostar todos os campos",
    ":ALL_CARDS_BARCODE": "C\u00f3digo de barras",
    ":ALL_CARDS_ACTIVE": "Ativo",
    ":ALL_CARDS_PRIMARY": "Prim\u00e1rio",
    ":ALL_CARDS_CLOSE": "Fechar",
    ":ALL_CARDS_APPLY": "Aplicar Altera\u00e7\u00f5es",
    ":INVALIDATE": "Invalidar",
    ":HOLD_NOTIFY_PHONE": "Telefone: ",
    ":HOLD_NOTIFY_EMAIL": "E-mail: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}
